A basic class to handle a SDMX Code
SDMXCode(xmlObj, namespaces)object of class "XMLInternalDocument derived from XML package
object of class "data.frame" given the list of namespace URIs
an object of class "SDMXCode"
idObject of class "character" giving the ID of the code (required). In SDMX 2.0 documents, this slot will handle the 'value' attribute
urnObject of class "character" giving the code urn
parentCodeObject of class "character" giving the parent code
labelObject of class "list" giving the code label (by language). In SDMX 2.0, it takes the code 'Description' element vs. 'Name' element in SDMX 2.1
This class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document (Codelists, or DataStructureDefinition)