A basic class to handle a SDMX DataStructures (or KeyFamilies)
SDMXDataStructures(xmlObj, namespaces)object of class "XMLInternalDocument derived from XML package
object of class "data.frame" given the list of namespace URIs
an object of class "SDMXDataStructures"
datastructuresObject of class "list" giving the list of DataStructures, (see SDMXDataStructure)
This class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document (Concepts, or DataStructureDefinition)