an object of class "character" giving the base Url of the SDMX
service registry
repoUrl
an object of class "character" giving the base Url of the SDMX
service repository
accessKey
an object of class "character" indicating the name of request parameter for which
an authentication or subscription user key/token has to be provided to perform requests
unsupportedResources
an object of class "list" giving eventual unsupported
REST resources. Default is an empty list object
skipProviderId
an object of class "logical" indicating that the provider
agencyIdshould be skipped. Used to control lack of strong SDMX REST compliance
from data providers. For now, it applies only for the "data" resource.
forceProviderId
an object of class "logical" indicating if the provider
agencyId has to be added at the end of the request. Default value is
FALSE. For some providers, the all value for the provider
agency id is not allowed, in this case, the agencyId of the data
provider has to be forced in the web-request
Slots
regUrl
an object of class "character" giving the base Url of the SDMX service registry
repoUrl
an object of class "character" giving the base Url of the SDMX service repository
accessKey
an object of class "character" indicating the name of request parameter for which
an authentication or subscription user key/token has to be provided to perform requests
compliant
an object of class "logical" indicating if the request builder is somehow compliant with a service specification
Warning
This class is not useful in itself, but all SDMX non-abstract classes will
encapsulate it as slot, when parsing an SDMX-ML document.
# NOT RUN {#how to create a SDMXDotStatRequestBuilder requestBuilder <- SDMXDotStatRequestBuilder(
regUrl = "http://www.myorg/registry",
repoUrl = "http://www.myorg/repository")
# }