A basic class to handle a footer message of a SDMX-ML document
SDMXFooterMessage(xmlObj)object of class "XMLInternalDocument derived from XML package
an object of class "SDMXFooterMessage"
codeObject of class "character" giving the status code
severityObject of class "character" giving the severity of the message
messagesObject of class "list" giving the list of messages
This class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document