A basic class to handle a SDMX OrganisationSchemes
SDMXOrganisationSchemes(xmlObj, namespaces)object of class "XMLInternalDocument derived from XML package
object of class "data.frame" given the list of namespace URIs
an object of class "OrganisationSchemes"
organisationSchemesObject of class "list" giving the list of SDMXAgencyScheme
This class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document