SDMXSchema: Class "SDMXSchema"
Description
A basic class to handle the version of the SDMX-ML Schema
Usage
SDMXSchema(xmlObj, namespaces)
Arguments
xmlObj
object of class "XMLInternalDocument derived from XML package
namespaces
object of class "data.frame" given the list of namespace URIs
Value
an object of class "SDMXSchema"
Slots
versionObject of class "character" giving the SDMX-ML schema version
Warning
this class is not useful in itself, but all SDMX non-abstract classes will
encapsulate it as slot, when parsing an SDMX-ML document.