A class to wrap a list of SDMX service providers
SDMXServiceProviders(providers)an object of class "list" (of SDMXServiceProvider) configured by default and/or at runtime in rsdmx
an object of class "SDMXServiceProviders"
providersan object of class "list" (of SDMXServiceProvider) configured by default and/or at runtime in rsdmx
this class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document.