Learn R Programming

rsdmx (version 0.5-9)

SDMXType: Class "SDMXType"

Description

A basic class to handle the type of a SDMX-ML document

Usage

SDMXType(xmlObj)

Arguments

xmlObj

object of class "XMLInternalDocument derived from XML package

Value

an object of class "SDMXType"

Slots

type

Object of class "character" giving the type of the SDMX-ML document

Warning

this class is not useful in itself, but all SDMX non-abstract classes will encapsulate it as slot, when parsing an SDMX-ML document.

See Also

readSDMX