Learn R Programming

rsdmx (version 0.5-9)

findNamespace: findNamespace

Description

function used to find a specific namespace within the available namespaces of an SDMX-ML object

Usage

findNamespace(namespaces, messageType)

Arguments

namespaces

object of class data.frame giving the namespaces URIs available in a SDMX-ML object, typically obtained with getNamespaces

messageType

object of class character representing a message type

Value

an object of class "character" giving the namespace uri if found in the available namespaces

Warning

findNamespace is a function used internally as utility function in SDMX-ML object parsers.

See Also

SDMX-class getNamespaces