function used to find a specific namespace within the available namespaces of an SDMX-ML object
findNamespace(namespaces, messageType)object of class data.frame giving the namespaces URIs
available in a SDMX-ML object, typically obtained with getNamespaces
object of class character representing a message type
an object of class "character" giving the namespace uri if found in the available namespaces
findNamespace is a function used internally as utility function in
SDMX-ML object parsers.